mui.init({
	gestureConfig: {
		longtap: true
	}
});
var DownloadUtil = require('scripts/Core/DownLoadUtil.js');
//下载图片列表
var picList = [];
//分享标题
var shareTitle = null;
var task_id=0;
//下载缓存池 格式{url:错误数量}
var downloadCache = {};
//存放图片下载成功和失败的数目
var downloadState = {
	success_count: 0,
	error_count: 0
};
//分享图片列表，图片本地绝对路径
var sharePictures = [];

mui.plusReady(function() {
	var param = plus.webview.currentWebview().param;
	picList = param.path.split('|');
	//添加图片元素
	addImgNode();
	shareTitle = param.title;
	task_id=param.task_id;
	//通过工具类下载文件,这里进行设置
	DownloadUtil.setOptions({
		//默认的下载缓存目录-存到应用的downloads/downloadFiles下
		'downloadStoragePath': "_downloads/imgs/",
		//本地缓存的时间戳,毫秒单位,默认为1天
		'fileCacheTimeStamp': 1000 * 60 * 60 * 24 * 1,
		//同时最多的downloader 并发下载数目,默认为3个
		'concurrentDownloadCount': 1,
		//超时请求时间
		'timeout': 3,
		//超时请求后的重试次数
		'retryInterval': 3,
		//单个下载任务最大的请求时间,防止一些机型上无法触发错误回调,单位毫秒,默认10秒
		'maxTimeSingleDownloadTaskSpend': 1000 * 10,
		//获取相对路径的函数,如果不传,则用默认的路径处理方法
		'getRelativePathFromLoadUrlCallback': function(loadUrl) {
			//获取图片后缀,如果没有获取到后缀,默认是jpg
			var imgSuffix = loadUrl.substring(loadUrl.lastIndexOf(".") + 1, loadUrl.length);
			if(
				imgSuffix.toLocaleLowerCase() != ("jpg") &&
				imgSuffix.toLocaleLowerCase() != ("jpeg") &&
				imgSuffix.toLocaleLowerCase() != ("png") &&
				imgSuffix.toLocaleLowerCase() != ("bmp") &&
				imgSuffix.toLocaleLowerCase() != ("svg") &&
				imgSuffix.toLocaleLowerCase() != ("gif")
			) {
				//如果后缀没有包含以上图片,将后缀改为jpg
				imgSuffix = 'jpg';
			}
			//更换存储方式,变为将整个路径存储下来,然后去除非法字符
			var regIllegal = /[&\|\\\*^%$#@\-:.?\/=!]/g;
			//获取图片名字
			var imgName = loadUrl.replace(regIllegal, '');
			//最终的名字
			var filename = imgName + '.' + imgSuffix;
			var relativePath = '_downloads/imgs/' + filename;
			return relativePath;
		}
	});
	addEvent();
	startDownload();
	
})

//根据返回的图片数组添加图片元素
function addImgNode() {
	var len = picList.length;
	var imgListObj = document.getElementById('downImg');
	for(var i = 0; i < len; i++) {
		var imgList = document.createElement('li');
		imgList.innerHTML = '<img src="../pic/loadingImg.png" />';
		imgListObj.appendChild(imgList);
	}
}

//开始下载图片
function startDownload() {
	//初始化下载状态
	downloadState.success_count = 0;
	downloadState.error_count = 0;
	//获取所有下载列表的所有img元素
	mui.each(document.querySelectorAll('#downImg img'), function(index, item) {
		downloadImgList(picList[index], item);
	});
}

//批量下载
function downloadImgList(src, dom) {
	var fileName = "#" + src.substr(src.lastIndexOf('/') + 1, 32);
	//创建进度条
	var processBar = new ProcessBar();
	var $dom = $(dom);
	//获取图片名字
	DownloadUtil.downloadFileWidthLocalCache(src, {
		beforeDownload: function() {
			$dom.parent().append(processBar.Container);
		},
		successDownload: function(relativePath) {
			mui.plusReady(function() {
				var sd_path = plus.io.convertLocalFileSystemURL(relativePath);
				//把图片保存到相册中
				//				plus.gallery.save(relativePath, function() {
				//					mui.toast("图片已保存到手机相册中");
				//				});
				setTimeout(function() {
					dom.setAttribute('src', sd_path);
					processBar.closePro();
				}, 200);
				sharePictures.push(sd_path);
				downloadState.success_count++;
				downloadCache[fileName] = null;
				checkDownloadFinish();
			});
		},
		downloading: function(progress, tips) {
			var sum = parseInt(progress);
			//设置进度条进度
			processBar.setProgress(sum);
		},
		errorDownload: function(msg) {
			if(downloadCache[fileName]) {
				downloadCache[fileName] = null; //清空缓存池	
				processBar.closePro();
				dom.setAttribute('src', '../pic/img_error.jpg');
				//第一次下载失败错误数量+1
				downloadState.error_count++;
				checkDownloadFinish();
			} else {
				downloadCache[fileName] = 1;
				//重新下载一次
				downloadImgList(src, dom);
			}
		}
	});
};

//检查是否完成所有下载
function checkDownloadFinish() {
	if(downloadState.success_count == picList.length) {
		//将排序后的图片给sharePicture
		sortPicList();
		//		mui.toast('所有图片下载成功！请从相册中查看图片');
		setButtonState("shareBtn", 0);
	}
	//下载过程完毕
	if((downloadState.success_count + downloadState.error_count) == picList.length) {
		sortPicList();
		if(downloadState.error_count > 0) {
			mui.alert('网络异常，有' + downloadState.error_count + '张图片下载失败,请稍后再试!');
		}
	}
}

//重新对图片列表排序
function sortPicList() {
	var temp = []; //临时列表
	if(picList && sharePictures && sharePictures.length > 0) {
		for(var i = 0; i < picList.length; i++) {
			for(var j = 0; j < sharePictures.length; j++) {

				//随机获取20个字符
				var searchName = sharePictures[j].substr(sharePictures[j].length - 30, 20);

				if(picList[i].indexOf(searchName) > 0) {
					temp.push(sharePictures[j]);
				}
			}
		}
		//重新把正确排序赋值
		sharePictures = temp;
	}
}

//设置按钮是否可用，1不可用 0可用 
function setButtonState(id, isDisabled) {
	//不可用
	if(isDisabled == 1) {
		//设为不可编辑状态
		document.getElementById(id).classList.add("mui-btn-grey");
		document.getElementById(id).classList.remove("btn_sure");
		document.getElementById(id).disabled = true;
	} else {
		//设为可编辑状态,恢复初始状态
		document.getElementById(id).disabled = false;
		document.getElementById(id).classList.add("btn_sure");
		document.getElementById(id).classList.remove("mui-btn-grey");

	}
}

//分享按钮绑定点击分享事件
function addEvent() {
	//初始化按钮
	setButtonState("shareBtn", 1);
	//弹出分享菜单
	document.getElementById('shareBtn').addEventListener('tap', function() {
		mui('#share_box').popover('toggle');
	});
	if(plus.os.name == "iOS") {
		//IOS系统分享
		document.getElementById('ios_shareSystem').addEventListener('tap', function() {
			plus.NativeShare.share({
				imgs: sharePictures
			}, function(suc) {
				helper.UmengTraPlus(2,"转发图片分享完成","任务ID",task_id.toString(),"标题",shareTitle);
				mui.toast("分享成功");
			}, function(err) {
				mui.toast("分享失败");
			});
		});
	} else {
		//android系统分享
		document.querySelector(".sharebtn_wx").addEventListener("tap", function() {
			mui('#share_box').popover('toggle');
			if(sharePictures && sharePictures.length > 0) {
				WeixinShare("转发客", sharePictures, shareTitle);
			}
		});
	}
}

//分享到系统，文字链接需要黏贴
function WeixinShare(tip, pics, description) {
	console.log("pics:" + JSON.stringify(pics));
	var Intent = plus.android.importClass('android.content.Intent');
	var ComponentName = plus.android.importClass('android.content.ComponentName');
	var ArrayList = plus.android.importClass('java.util.ArrayList');
	var Uri = plus.android.importClass('android.net.Uri');
	var Environment = plus.android.importClass('android.os.Environment');
	var File = plus.android.importClass('java.io.File');
	//var sdcardDir = plus.android.invoke(Environment.getExternalStorageDirectory(),'getAbsolutePath');
	var intent = new Intent();
	intent.setAction("android.intent.action.SEND_MULTIPLE");
	intent.setType("image/*");
	var localArrayList = new ArrayList();
	for(var i = 0; i < pics.length; i++) {
		var filePath = pics[i];
		localArrayList.add(Uri.fromFile(new File(filePath)));
	}
	intent.putParcelableArrayListExtra("android.intent.extra.STREAM", localArrayList);

	intent.putExtra(Intent.EXTRA_TEXT, description);
	var act = plus.android.runtimeMainActivity();
	act.startActivity(Intent.createChooser(intent, tip));
}